<?php
/**
 * A Initialization filter for servers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2013 LFDB2 Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ServerInitializationFilter extends BaseServerFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createServerInitializationFilter () {
		// Get a new instance
		$filterInstance = new ServerInitializationFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		$this->partialStub('Unported.');
		die();

		// The default node-mode is from our configuration
		$nodeMode = $this->getConfigInstance()->getConfigEntry('node_default_mode');
		//* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[INIT:] Got default node mode ' . $nodeMode . ' from configuration.');

		// Is the node 'mode' parameter set?
		if ($requestInstance->isRequestElementSet('mode')) {
			// Then use this which overrides the config entry temporarily
			$nodeMode = $requestInstance->getRequestElement('mode');
		} else {
			// Set it for easier re-usage
			$requestInstance->setRequestElement('mode', $nodeMode);
		}

		// Now convert the node-mode in a class name
		$className = 'Lfdb2' . self::convertToClassName($nodeMode) . 'Server';

		// And try to instance it
		try {
			// Get an instance
			$nodeInstance = ObjectFactory::createObjectByName($className, array($requestInstance));

			// Get a registry
			$applicationInstance = Registry::getRegistry()->getInstance('app');

			// Set the app instance
			$nodeInstance->setApplicationInstance($applicationInstance);

			// Add node-specific filters
			$nodeInstance->addExtraFilters($applicationInstance->getControllerInstance(), $responseInstance);
		} catch (ClassNotFoundException $e) {
			// This exception means, the node mode is invalid.
			// @TODO Can we rewrite this to app_exit() ?
			$this->debugBackTrace('[' . __METHOD__ . ':' . __LINE__ . ']:  node mode ' . $nodeMode . ' is invalid.');
		}

		// Set the node instance in registry
		Registry::getRegistry()->addInstance('node', $nodeInstance);
		//* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[INIT:] Server ' . $nodeMode . ' has been added to registry.');
	}
}

// [EOF]
?>
