<?php
/**
 * A ShutdownServer filter for shutting down the server. This filter should be the
 * last one in 'shutdown' chain so the hub is shutted down at the very end of
 * its life... R.I.P. little hub...
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2013 LFDB2 Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ServerShutdownServerFilter extends BaseServerFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createServerShutdownServerFilter () {
		// Get a new instance
		$filterInstance = new ServerShutdownServerFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If $serverInstance is null (no NullPointerException please)
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get server instance
		$serverInstance = Registry::getRegistry()->getInstance('server');

		// Shutdown the server. This should be the last line
		$serverInstance->doShutdown();
	}
}

// [EOF]
?>
